aboutsummaryrefslogtreecommitdiff
path: root/pkg
diff options
context:
space:
mode:
Diffstat (limited to 'pkg')
-rw-r--r--pkg/config/config.go6
1 files changed, 5 insertions, 1 deletions
diff --git a/pkg/config/config.go b/pkg/config/config.go
index 31012a1..bfaefdf 100644
--- a/pkg/config/config.go
+++ b/pkg/config/config.go
@@ -104,7 +104,7 @@ func (opt GlobalOptions) WithPartHtml() bool {
return util.StrContains(opt.Parts, "html")
}
// Load configuration from file
func Load(path string) (*Config, error) {
log.Printf("Reading configuration file '%s'", path)
@@ -118,6 +118,10 @@ func Load(path string) (*Config, error) {
return nil, fmt.Errorf("while parsing: %w", err)
}
+ if err = cfg.Validate(); err != nil {
+ return nil, fmt.Errorf("Configuration invalid: %w", err)
+ }
+
return cfg, nil
}
@@ -104,7 +104,7 @@ func (opt GlobalOptions) WithPartHtml() bool {
return util.StrContains(opt.Parts, "html")
}
-// Load configuration from file
+// Load configuration from file and validate it
func Load(path string) (*Config, error) {
log.Printf("Reading configuration file '%s'", path)